Jump to content

Seal of Command


Auntie Mangos

Recommended Posts

But if you remove whirlwind there it doesn't do any offhand dmg :(.

I'm really wondering what is the reason that the offhand spell is not triggering, this implementation would be much better than the current because in my opinion now the offhand part of whirlwind takes benefit from attack power two times (firstly in the offhand damage calculation and then in the whole calculation af the spell :() and also can't be dodged/parried/miss etc. and crits if main hand crits (there is a thread about it in bug reports - http://getmangos.eu/community/viewtopic.php?id=10143).

Link to comment
Share on other sites

  • 39 years later...

What does it change:

Seal of Command shouldn't recieve any spell damage bonus after 3.2.# client switch

Judgement of Command however should have been increased by both Attack Power and Spell Power since early 3.#.# releases

diff --git a/src/game/SpellEffects.cpp b/src/game/SpellEffects.cpp
index 5e390b3..da4bd02 100644
--- a/src/game/SpellEffects.cpp
+++ b/src/game/SpellEffects.cpp
@@ -4401,14 +4401,8 @@ void Spell::EffectWeaponDmg(uint32 i)
    {
        case SPELLFAMILY_WARRIOR:
        {
-            // Whirlwind, single only spell with 2 weapon white damage apply if have
-            if(m_caster->GetTypeId()==TYPEID_PLAYER && (m_spellInfo->SpellFamilyFlags & UI64LIT(0x00000400000000)))
-            {
-                if(((Player*)m_caster)->GetWeaponForAttack(OFF_ATTACK,true))
-                    spell_bonus += m_caster->CalculateDamage (OFF_ATTACK, normalized);
-            }
            // Devastate bonus and sunder armor refresh
-            else if(m_spellInfo->SpellVisual[0] == 12295 && m_spellInfo->SpellIconID == 1508)
+            if(m_spellInfo->SpellVisual[0] == 12295 && m_spellInfo->SpellIconID == 1508)
            {
                uint32 stack = 0;
                // Need refresh all Sunder Armor auras from this caster
@@ -4627,27 +4621,6 @@ void Spell::EffectWeaponDmg(uint32 i)
        if(m_caster->GetTypeId()==TYPEID_PLAYER)
            ((Player*)m_caster)->AddComboPoints(unitTarget, 1);
    }
-    else if(m_spellInfo->SpellFamilyName==SPELLFAMILY_PALADIN)
-    {
-        // Judgement of Blood/of the Martyr backlash damage (33%)
-        if(m_spellInfo->SpellFamilyFlags & 0x0000000800000000LL && m_spellInfo->SpellIconID==153)
-        {
-            int32 damagePoint  = m_damage * 33 / 100;
-            if(m_spellInfo->Id == 31898)
-                m_caster->CastCustomSpell(m_caster, 32220, &damagePoint, NULL, NULL, true);
-            else
-                m_caster->CastCustomSpell(m_caster, 53725, &damagePoint, NULL, NULL, true);
-        }
-        // Seal of Blood/of the Martyr backlash damage (10%)
-        else if(m_spellInfo->SpellIconID==2293)
-        {
-            int32 damagePoint  = m_damage * 10 / 100;
-            if(m_spellInfo->Id == 31893)
-                m_caster->CastCustomSpell(m_caster, 32221, &damagePoint, NULL, NULL, true);
-            else
-                m_caster->CastCustomSpell(m_caster, 53718, &damagePoint, NULL, NULL, true);
-        }
-    }

    // take ammo
    if(m_attackType == RANGED_ATTACK && m_caster->GetTypeId() == TYPEID_PLAYER)

Link to comment
Share on other sites

Guest
This topic is now closed to further replies.
×
×
  • Create New...

Important Information

We have placed cookies on your device to help make this website better. You can adjust your cookie settings, otherwise we'll assume you're okay to continue. Privacy Policy Terms of Use
diff --git a/src/game/SpellEffects.cpp b/src/game/SpellEffects.cpp
index 1a0b9d4..5e390b3 100644
--- a/src/game/SpellEffects.cpp
+++ b/src/game/SpellEffects.cpp
@@ -4472,12 +4472,12 @@ void Spell::EffectWeaponDmg(uint32 i)
        }
        case SPELLFAMILY_PALADIN:
        {
-            // Seal of Command - receive benefit from Spell Damage and Healing
-            if(m_spellInfo->SpellFamilyFlags & UI64LIT(0x00000002000000))
+            // Judgement of Command - receive benefit from Spell Damage and Attack Power
+            if(m_spellInfo->SpellFamilyFlags & UI64LIT(0x00020000000000))
            {
                spellBonusNeedWeaponDamagePercentMod = true;// apply weaponDamagePercentMod to spell_bonus (and then to all bonus, fixes and weapon already have applied)
-                spell_bonus += int32(0.23f*m_caster->SpellBaseDamageBonus(GetSpellSchoolMask(m_spellInfo)));
-                spell_bonus += int32(0.29f*m_caster->SpellBaseDamageBonusForVictim(GetSpellSchoolMask(m_spellInfo), unitTarget));
+                spell_bonus += int32(0.08f*m_caster->GetTotalAttackPowerValue(BASE_ATTACK));
+                spell_bonus += int32(0.13f*m_caster->SpellBaseDamageBonus(GetSpellSchoolMask(m_spellInfo)));
            }
            break;
        }

EDIT: I'll not spam forums with very similar threads, I've just noticed few more ( mostly Paladin ) functions outdated in same function:

* Old removed Seals ( no longer exist in game )

* Whirlwind recieving offhand damage ( Off-hand damage should be handled by triggering another spell )
